import static db.JdbcUtil.close;
import static db.JdbcUtil.getConnection;

import java.sql.*;
import java.util.Scanner;
import static db.JdbcUtil.*;

public class BoardSVC {

	Connection con;
	public BoardVO getBoardVO(Scanner sc) {
		
		System.out.println("===게시물 등록===");
		System.out.print("작성자 : ");
		String writer = sc.next();
		System.out.print("비밀번호 : ");
		String passwd = sc.next();
		System.out.print("제목 : ");
		String subject = sc.next();
		System.out.print("이메일 : ");
		String email = sc.next();
			
		BoardVO boardVO = new BoardVO(0, writer, passwd, subject, email);
		return boardVO;
	}
	public void writeArticle(Scanner sc) {
		BoardVO boardVO = getBoardVO(sc);
		con = getConnection();
		PreparedStatement pstmt = null;
		
		String sql = "INSERT INTO board VALUES(board_seq.nextval,?,?,?,?)";
		try{
			pstmt = con.prepareStatement(sql);
			pstmt.setString(1, boardVO.getWriter());
			pstmt.setString(2,boardVO.getPasswd() );
			pstmt.setString(3, boardVO.getSubject());
			pstmt.setString(4, boardVO.getEmail());
			
			int count = pstmt.executeUpdate();
			if(count > 0){
				commit(con);
			}
			else{
				rollback(con);
			}
		}
		catch(Exception e){
			e.printStackTrace();
		}
		finally{
			close(pstmt);
			close(con);
		}		
	}
	public void showArticleList() {
		con = getConnection();
		PreparedStatement pstmt = null;
		ResultSet rs = null;
		String sql = "SELECT * FROM board";
		try{
			pstmt = con.prepareStatement(sql);
			rs = pstmt.executeQuery();
			while(rs.next()){
				System.out.println("id = " + rs.getInt("id") +
						", 작성자 = " + rs.getString("writer")
						+ ", 제목 = " + rs.getString("subject") +
						", 이메일 = " + rs.getString("email"));
			}
		}
		catch(Exception e){
			e.printStackTrace();
		}
		finally{
			close(rs);
			close(pstmt);
			close(con);
		}
	}
	public void showArticle(Scanner sc) {
		System.out.println("검색할 글 아이디를 입력하세요");
		System.out.print("글 아이디 : ");
		int id = sc.nextInt();
		BoardVO boardVO = getArticle(id);
		System.out.println(boardVO);
	}
	private BoardVO getArticle(int id) {
		// TODO Auto-generated method stub
		BoardVO boardVO = null;
		con = getConnection();
		PreparedStatement pstmt = null;
		ResultSet rs = null;
		String sql = "SELECT * FROM board WHERE id = ?";
		try{
			pstmt = con.prepareStatement(sql);
			pstmt.setInt(1, id);
			rs = pstmt.executeQuery();
			if(rs.next()){
				int dbId = rs.getInt("id");
				String writer = rs.getString("writer");
				String passwd = rs.getString("passwd");
				String subject = rs.getString("subject");
				String email = rs.getString("email");
				boardVO = new BoardVO(dbId, writer, passwd, subject, email);
			}
		}
		catch(Exception e){
			e.printStackTrace();
		}
		finally{
			close(rs);
			close(pstmt);
			close(con);
		}
		return boardVO;
	}
	public void deleteArticle(Scanner sc) {
		// TODO Auto-generated method stub
		System.out.println("삭제할 글 아이디를 입력하세요");
		System.out.print("글 아이디 : ");
		int id = sc.nextInt();
		
		int count = deleteArticle(id);
		if(count > 0){
			commit(con);
		}
		else{
			rollback(con);
		}
	}
	private int deleteArticle(int id) {
		// TODO Auto-generated method stub
		int deleteCount = 0;
		con = getConnection();
		PreparedStatement pstmt = null;
		
		String sql = "DELETE board WHERE id = ?";
		try{
			pstmt = con.prepareStatement(sql);
			pstmt.setInt(1, id);		
			deleteCount = pstmt.executeUpdate();
		}
		catch(Exception e){
			e.printStackTrace();
		}
		finally{
			close(pstmt);
			close(con);
		}		
		return deleteCount;
	}
	public void updateArticle(Scanner sc) {
		// TODO Auto-generated method stub
		System.out.println("수정할 글의 아이디를 입력하세요");
		System.out.print("글 아이디 : ");
		int id = sc.nextInt();
		
		BoardVO boardVO = getArticle(id);
		System.out.println("수정할 데이터를 입력하세요");
		System.out.println("원래 작성자 : " + boardVO.getWriter());
		System.out.print("수정할 작성자 : ");
		String writer = sc.next();
		
		System.out.println("원래 비밀번호 : " + boardVO.getPasswd());
		System.out.print("수정할 비밀번호 : ");
		String passwd = sc.next();
		
		System.out.println("원래 제목 : " + boardVO.getSubject());
		System.out.print("수정할 제목 : ");
		String subject = sc.next();
		
		System.out.println("원래 이메일 : " + boardVO.getEmail());
		System.out.print("수정할 이메일 : ");
		String email = sc.next();
		
		boardVO.setWriter(writer);
		boardVO.setPasswd(passwd);
		boardVO.setSubject(subject);
		boardVO.setEmail(email);
		
		int count = updateArticle(boardVO);
		if(count > 0){
			commit(con);
		}
		else{
			rollback(con);
		}
	}
	private int updateArticle(BoardVO boardVO) {
		// TODO Auto-generated method stub
		int updateCount = 0;
		con = getConnection();
		PreparedStatement pstmt = null;
		
		String sql = "UPDATE board SET writer = ?,passwd = ?, subject = ?, email = ?" +
				" WHERE id = ?";
		try{
			pstmt = con.prepareStatement(sql);
			pstmt.setString(1, boardVO.getWriter());		
			pstmt.setString(2, boardVO.getPasswd());	
			pstmt.setString(3, boardVO.getSubject());
			pstmt.setString(4, boardVO.getEmail());
			pstmt.setInt(5, boardVO.getId());
			updateCount = pstmt.executeUpdate();
		}
		catch(Exception e){
			e.printStackTrace();
		}
		finally{
			close(pstmt);
			close(con);
		}		
		return updateCount;
	}

}

